@@ -4,14 +4,10 @@ __all__ = ['CSSParser']
 from .helper import path2url
 import codecs
 import cssutils
-import sys
 from . import tokenize2
 
 from cssutils import css
 
-if sys.version_info < (2, 6):
-    bytes = str
-
 
 class CSSParser(object):
     """Parse a CSS StyleSheet from URL, string or file and return a DOM Level 2
