@@ -27,3 +27,6 @@ link_files = {
         ],
     )
 }
+
+# Be strict about any broken references:
+nitpicky = True
